@@ -15,6 +15,17 @@ pub(crate) fn extract_symbol(market_type: MarketType, msg: &str) -> Result<Strin
     }
 }
 
+pub(crate) fn extract_timestamp(
+    market_type: MarketType,
+    msg: &str,
+) -> Result<Option<i64>, SimpleError> {
+    if market_type == MarketType::Spot {
+        zbg_spot::extract_timestamp(msg)
+    } else {
+        zbg_swap::extract_timestamp(market_type, msg)
+    }
+}
+
 pub(crate) fn parse_trade(
     market_type: MarketType,
     msg: &str,
