@@ -30,12 +30,12 @@ pub(super) fn extract_timestamp(msg: &str) -> Result<Option<i64>, SimpleError> {
     if let Ok(list) = serde_json::from_str::<Vec<Vec<Value>>>(msg) {
         let timestamp = if msg.starts_with(r#"[["T","#) {
             let timestamp = list.iter().fold(std::i64::MIN, |a, raw_trade| {
-                a.max(raw_trade[2].as_str().unwrap().parse::<i64>().unwrap())
+                a.max(raw_trade[2].as_str().unwrap().parse::<i64>().unwrap() * 1000)
             });
             timestamp
         } else {
             let timestamp = list.iter().fold(std::i64::MIN, |a, raw_trade| {
-                a.max(raw_trade[3].as_str().unwrap().parse::<i64>().unwrap())
+                a.max(raw_trade[3].as_str().unwrap().parse::<i64>().unwrap() * 1000)
             });
             timestamp
         };
@@ -45,7 +45,9 @@ pub(super) fn extract_timestamp(msg: &str) -> Result<Option<i64>, SimpleError> {
             Ok(Some(timestamp))
         }
     } else if let Ok(list) = serde_json::from_str::<Vec<Value>>(msg) {
-        Ok(Some(list[2].as_str().unwrap().parse::<i64>().unwrap()))
+        Ok(Some(
+            list[2].as_str().unwrap().parse::<i64>().unwrap() * 1000,
+        ))
     } else {
         Err(SimpleError::new(format!(
             "Failed to extract symbol from {}",
