@@ -3,7 +3,7 @@ mod utils;
 #[cfg(test)]
 mod trade {
     use crypto_market_type::MarketType;
-    use crypto_msg_parser::{extract_symbol, parse_trade, TradeSide};
+    use crypto_msg_parser::{extract_symbol, extract_timestamp, parse_trade, TradeSide};
 
     #[test]
     fn spot_te() {
@@ -18,6 +18,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1615232733897,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.quantity_base, 0.11546588);
         assert_eq!(trade.quantity_quote, 0.11546588 * 51350.0);
@@ -39,6 +43,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1615232733897,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.quantity_base, 0.11546588);
         assert_eq!(trade.quantity_quote, 0.11546588 * 51350.0);
@@ -64,6 +72,10 @@ mod trade {
                 raw_msg,
             );
         }
+        assert_eq!(
+            1616217509543,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, None).unwrap()
+        );
     }
 
     #[test]
@@ -79,6 +91,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1616219711336,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.quantity_base, 0.00020449);
         assert_eq!(trade.quantity_quote, 0.00020449 * 58244.0);
@@ -100,6 +116,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1616219711336,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.quantity_base, 0.00020449);
         assert_eq!(trade.quantity_quote, 0.00020449 * 58244.0);
@@ -125,6 +145,10 @@ mod trade {
                 raw_msg,
             );
         }
+        assert_eq!(
+            1616219105954,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, None).unwrap()
+        );
     }
 }
 
@@ -132,19 +156,15 @@ mod trade {
 mod l2_orderbook {
     use chrono::prelude::*;
     use crypto_market_type::MarketType;
-    use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_parser::{extract_symbol, extract_timestamp, parse_l2};
     use crypto_msg_type::MessageType;
 
     #[test]
     fn spot_snapshot() {
         let raw_msg = r#"[{"symbol":"tBTCUST","len":"25","freq":"F0","channel":"book","prec":"P0"},[[36167,1,0.48403686],[36162,2,0.22625024],[36161,1,0.43250047],[36158,1,0.209],[36155,2,0.48229814],[36171,1,-0.000006],[36172,1,-0.0002],[36173,1,-0.0002],[36174,2,-0.0102],[36175,1,-0.0002]]]"#;
-        let orderbook = &parse_l2(
-            "bitfinex",
-            MarketType::Spot,
-            raw_msg,
-            Some(Utc::now().timestamp_millis()),
-        )
-        .unwrap()[0];
+        let received_at = Utc::now().timestamp_millis();
+        let orderbook =
+            &parse_l2("bitfinex", MarketType::Spot, raw_msg, Some(received_at)).unwrap()[0];
 
         assert_eq!(orderbook.asks.len(), 5);
         assert_eq!(orderbook.bids.len(), 5);
@@ -159,6 +179,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            received_at,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, Some(received_at)).unwrap()
+        );
 
         assert_eq!(orderbook.bids[0].price, 36167.0);
         assert_eq!(orderbook.bids[0].quantity_base, 0.48403686);
@@ -180,13 +204,9 @@ mod l2_orderbook {
     #[test]
     fn spot_update() {
         let raw_msg = r#"[{"symbol":"tBTCUST","channel":"book","len":"25","freq":"F0","prec":"P0"},[34668,1,-0.00813136]]"#;
-        let orderbook = &parse_l2(
-            "bitfinex",
-            MarketType::Spot,
-            raw_msg,
-            Some(Utc::now().timestamp_millis()),
-        )
-        .unwrap()[0];
+        let received_at = Utc::now().timestamp_millis();
+        let orderbook =
+            &parse_l2("bitfinex", MarketType::Spot, raw_msg, Some(received_at)).unwrap()[0];
 
         assert_eq!(orderbook.asks.len(), 1);
         assert_eq!(orderbook.bids.len(), 0);
@@ -201,6 +221,11 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            received_at,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, Some(received_at)).unwrap()
+        );
+
         assert_eq!(orderbook.asks[0].price, 34668.0);
         assert_eq!(orderbook.asks[0].quantity_base, 0.00813136);
         assert_eq!(orderbook.asks[0].quantity_quote, 34668.0 * 0.00813136);
@@ -209,11 +234,12 @@ mod l2_orderbook {
     #[test]
     fn linear_swap_snapshot() {
         let raw_msg = r#"[{"freq":"F0","channel":"book","prec":"P0","len":"25","symbol":"tBTCF0:USTF0"},[[34840,2,0.20047952],[34837,1,0.17573],[34829,1,0.0857],[34828,1,0.17155],[34826,2,0.25510833],[34841,1,-0.00034929],[34843,4,-0.70368583],[34844,1,-0.51672161],[34845,2,-0.78960194],[34846,1,-1.0339621]]]"#;
+        let received_at = Utc::now().timestamp_millis();
         let orderbook = &parse_l2(
             "bitfinex",
             MarketType::LinearSwap,
             raw_msg,
-            Some(Utc::now().timestamp_millis()),
+            Some(received_at),
         )
         .unwrap()[0];
 
@@ -230,6 +256,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            received_at,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, Some(received_at)).unwrap()
+        );
 
         assert_eq!(orderbook.bids[0].price, 34840.0);
         assert_eq!(orderbook.bids[0].quantity_base, 0.20047952);
@@ -255,11 +285,12 @@ mod l2_orderbook {
     #[test]
     fn linear_swap_update() {
         let raw_msg = r#"[{"freq":"F0","symbol":"tBTCF0:USTF0","channel":"book","len":"25","prec":"P0"},[34442,2,2.27726294]]"#;
+        let received_at = Utc::now().timestamp_millis();
         let orderbook = &parse_l2(
             "bitfinex",
             MarketType::LinearSwap,
             raw_msg,
-            Some(Utc::now().timestamp_millis()),
+            Some(received_at),
         )
         .unwrap()[0];
 
@@ -276,6 +307,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            received_at,
+            extract_timestamp("bitfinex", MarketType::Spot, raw_msg, Some(received_at)).unwrap()
+        );
 
         assert_eq!(orderbook.bids[0].price, 34442.0);
         assert_eq!(orderbook.bids[0].quantity_base, 2.27726294);
