@@ -3,7 +3,7 @@ mod utils;
 #[cfg(test)]
 mod trade {
     use crypto_market_type::MarketType;
-    use crypto_msg_parser::{extract_symbol, parse_trade, TradeSide};
+    use crypto_msg_parser::{extract_symbol, extract_timestamp, parse_trade, TradeSide};
 
     #[test]
     fn inverse_future() {
@@ -22,6 +22,10 @@ mod trade {
                 raw_msg,
             );
         }
+        assert_eq!(
+            1616304614117,
+            extract_timestamp("bybit", MarketType::InverseFuture, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trades[0].quantity_base, 100.0 / 61094.5);
         assert_eq!(trades[0].quantity_quote, 100.0);
@@ -51,6 +55,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1616304710061,
+            extract_timestamp("bybit", MarketType::InverseSwap, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.quantity_base, 237.0 / 57073.5);
         assert_eq!(trade.quantity_quote, 237.0);
@@ -75,6 +83,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1616304737092,
+            extract_timestamp("bybit", MarketType::LinearSwap, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.quantity_base, 0.04);
         assert_eq!(trade.quantity_quote, 0.04 * 57170.0);
@@ -86,7 +98,7 @@ mod trade {
 #[cfg(test)]
 mod l2_orderbook {
     use crypto_market_type::MarketType;
-    use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_parser::{extract_symbol, extract_timestamp, parse_l2};
     use crypto_msg_type::MessageType;
 
     #[test]
@@ -107,6 +119,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1622538339073,
+            extract_timestamp("bybit", MarketType::InverseFuture, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1622538339073);
 
@@ -149,6 +165,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1622540847513,
+            extract_timestamp("bybit", MarketType::InverseFuture, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1622540847513);
 
@@ -186,6 +206,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1622542809357,
+            extract_timestamp("bybit", MarketType::InverseFuture, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1622542809357);
 
@@ -228,6 +252,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1622542809497,
+            extract_timestamp("bybit", MarketType::InverseFuture, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1622542809497);
 
@@ -265,6 +293,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1622543529282,
+            extract_timestamp("bybit", MarketType::LinearSwap, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1622543529282);
 
@@ -307,6 +339,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1622544088904,
+            extract_timestamp("bybit", MarketType::LinearSwap, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1622544088904);
 
