@@ -3,7 +3,7 @@ mod utils;
 #[cfg(test)]
 mod trade {
     use crypto_market_type::MarketType;
-    use crypto_msg_parser::{extract_symbol, parse_trade, TradeSide};
+    use crypto_msg_parser::{extract_symbol, extract_timestamp, parse_trade, TradeSide};
 
     #[test]
     fn spot() {
@@ -21,6 +21,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1646311839593,
+            extract_timestamp("okx", MarketType::Spot, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.timestamp, 1646311839593);
         assert_eq!(trade.quantity_base, 0.00373695);
@@ -45,6 +49,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1646311972504,
+            extract_timestamp("okx", MarketType::LinearFuture, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.timestamp, 1646311972504);
         assert_eq!(trade.price, 43535.3);
@@ -70,6 +78,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1646312440645,
+            extract_timestamp("okx", MarketType::LinearSwap, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.timestamp, 1646312440645);
         assert_eq!(trade.price, 43568.8);
@@ -95,6 +107,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1646312543604,
+            extract_timestamp("okx", MarketType::InverseFuture, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.timestamp, 1646312543604);
         assert_eq!(trade.price, 43568.7);
@@ -120,6 +136,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1646312664791,
+            extract_timestamp("okx", MarketType::InverseSwap, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.timestamp, 1646312664791);
         assert_eq!(trade.price, 43574.9);
@@ -145,6 +165,10 @@ mod trade {
             trade,
             raw_msg,
         );
+        assert_eq!(
+            1646138219181,
+            extract_timestamp("okx", MarketType::EuropeanOption, raw_msg, None).unwrap()
+        );
 
         assert_eq!(trade.timestamp, 1646138219181);
         assert_eq!(trade.price, 0.001);
@@ -198,7 +222,7 @@ mod funding_rate {
 #[cfg(test)]
 mod l2_orderbook {
     use crypto_market_type::MarketType;
-    use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_parser::{extract_symbol, extract_timestamp, parse_l2};
     use crypto_msg_type::MessageType;
 
     #[test]
@@ -219,6 +243,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1646313944551,
+            extract_timestamp("okx", MarketType::Spot, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1646313944551);
 
@@ -249,6 +277,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1646314295200,
+            extract_timestamp("okx", MarketType::Spot, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1646314295200);
 
@@ -279,6 +311,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1646314548269,
+            extract_timestamp("okx", MarketType::LinearFuture, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1646314548269);
 
@@ -311,6 +347,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1646314888087,
+            extract_timestamp("okx", MarketType::InverseSwap, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1646314888087);
 
@@ -343,6 +383,10 @@ mod l2_orderbook {
             orderbook,
             raw_msg,
         );
+        assert_eq!(
+            1646315100798,
+            extract_timestamp("okx", MarketType::EuropeanOption, raw_msg, None).unwrap()
+        );
 
         assert_eq!(orderbook.timestamp, 1646315100798);
 
